@@ -3,7 +3,7 @@ from .create_database import CreateDatabase
 from .create_predictor import CreatePredictor
 from .drop_predictor import DropPredictor
 from .retrain_predictor import RetrainPredictor
-from .adjust_predictor import AdjustPredictor
+from .finetune_predictor import FinetunePredictor
 from .drop_integration import DropIntegration
 from .drop_datasource import DropDatasource
 from .drop_dataset import DropDataset
