@@ -26,7 +26,7 @@ class MindsDBLexer(Lexer):
         PREDICTOR, PREDICTORS, DATASOURCE, INTEGRATION, INTEGRATIONS,DATASOURCES,
         STREAM, STREAMS, PUBLICATION, PUBLICATIONS, VIEW, VIEWS, DATASETS, DATASET,
         MODEL, MODELS, ML_ENGINE, ML_ENGINES, HANDLERS,
-        ADJUST,
+        FINETUNE,
         LATEST, HORIZON, USING,
         ENGINE, TRAIN, PREDICT, PARAMETERS, JOB, EVERY,
 
@@ -73,7 +73,7 @@ class MindsDBLexer(Lexer):
     }
 
     RETRAIN = r'\bRETRAIN\b'
-    ADJUST = r'\bADJUST\b'
+    FINETUNE = r'\bFINETUNE\b'
     # Custom commands
 
     USE = r'\bUSE\b'
